package Task::BeLike::BURAK;
$Task::BeLike::BURAK::VERSION = '0.28';
use strict;
use warnings;

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Task::BeLike::BURAK

=head1 VERSION

version 0.28

=head1 SYNOPSIS

None.

=head1 DESCRIPTION

This is a tool to install the modules I like.

=head1 NAME

Task::BeLike::BURAK - Installs all modules I (BURAK) like

=head1 PREREQUISITIES

See the meta files in the distribution.

=head1 AUTHOR

Burak Gursoy

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by Burak Gursoy.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
